@@ -3,7 +3,12 @@
 Display a raw_data_id.
 """
 
+import sys
 import os
+import logging
+logging.basicConfig(format='%(asctime)s %(levelname)s %(message)s',
+                    level=logging.DEBUG,
+                    stream=sys.stdout)
 import yaml
 import MySQLdb
 import MySQLdb.cursors
@@ -42,14 +47,22 @@ def display_data(raw_data_string, raw_data_id, model_folder):
 
     # Get model description
     model_description_file = os.path.join(model_folder, "info.yml")
+    if not os.path.isfile(model_description_file):
+        logging.error("You are probably not in the folder of a model, because "
+                      "%s is not a file. (-m argument)",
+                      model_description_file)
+        sys.exit(-1)
     with open(model_description_file, 'r') as ymlfile:
         model_description = yaml.load(ymlfile)
 
     # Get the feature description
-    feature_description_file = os.path.join(
-        PROJECT_ROOT,
-        model_description['data-source'],
-        "info.yml")
+    feature_description_file = os.path.join(PROJECT_ROOT,
+                                            model_description['data-source'],
+                                            "info.yml")
+    if not os.path.isfile(feature_description_file):
+        logging.error("You are probably not in the folder of a model, because "
+                      "%s is not a file.", feature_description_file)
+        sys.exit(-1)
     with open(feature_description_file, 'r') as ymlfile:
         feature_description = yaml.load(ymlfile)
 
