@@ -370,9 +370,49 @@ class Space_evenly_per_stroke(object):
 
         for stroke in pointlist:
             new_stroke = []
-            if len(stroke) < 4:
-                # Don't do anything if there are less than 4 points
+            if len(stroke) < 2:
+                # Don't do anything if there are less than 2 points
                 new_stroke = stroke
+            if 2 <= len(stroke) <= 3:
+                # Linear interpolation for 2 or 3 points
+                # TODO: This is much code duplication. Can this be done better?
+                stroke = sorted(stroke, key=lambda p: p['time'])
+
+                x, y, t = [], [], []
+
+                for point in stroke:
+                    x.append(point['x'])
+                    y.append(point['y'])
+                    t.append(point['time'])
+
+                x, y = numpy.array(x), numpy.array(y)
+                failed = False
+                try:
+                    fx = interp1d(t, x, kind='linear')
+                    fy = interp1d(t, y, kind='linear')
+                except Exception as e:
+                    if handwritten_data.raw_data_id is not None:
+                        logging.debug("spline failed for raw_data_id %i",
+                                      handwritten_data.raw_data_id)
+                    else:
+                        logging.debug("spline failed")
+                    logging.debug(e)
+                    failed = True
+
+                tnew = numpy.linspace(t[0], t[-1], self.number)
+
+                # linear interpolation fallback due to
+                # https://github.com/scipy/scipy/issues/3868
+                if failed:
+                    try:
+                        fx = interp1d(t, x, kind='linear')
+                        fy = interp1d(t, y, kind='linear')
+                        failed = False
+                    except Exception as e:
+                        raise e
+
+                for x, y, t in zip(fx(tnew), fy(tnew), tnew):
+                    new_stroke.append({'x': x, 'y': y, 'time': t})
             else:
                 stroke = sorted(stroke, key=lambda p: p['time'])
 
