@@ -105,7 +105,8 @@ def get_latest_folder(folder):
 
 def get_database_config_file():
     """Get the absolute path to the database configuration file."""
-    return os.path.join(get_project_root(), "tools/db.config.yml")
+    cfg = get_project_configuration()
+    return cfg['dbconfig']
 
 
 def get_database_configuration():
